@@ -3,8 +3,8 @@
 ;; Copyright (C) 2021 Isa Mert Gurbuz
 
 ;; Author: Isa Mert Gurbuz <isamert@protonmail.com>
-;; Package-Version: 1.0.2
-;; Package-Revision: 416b2d6e9a9d
+;; Package-Version: 1.1.0
+;; Package-Revision: 4f24d187e2bf
 ;; URL: https://github.com/isamert/orgmdb.el
 ;; Package-Requires: ((emacs "27.1") (dash "2.11.0") (s "1.12.0") (org "8.0.0"))
 
@@ -180,6 +180,16 @@ under the header."
   :type 'string
   :group 'orgmdb)
 
+(defcustom orgmdb-not-available-property-value "N/A"
+  "String used as a placeholder when a property value is unavailable.
+
+When non-nil, OrgMDB inserts this string for any property whose value
+cannot be determined while filling properties (i.e. not returned from
+OMDB).  When nil, OrgMDB skips creating such properties entirely instead
+of inserting a placeholder."
+  :type 'string
+  :group 'orgmdb)
+
 ;;;###autoload
 (defvar orgmdb-omdb-url
   "https://www.omdbapi.com"
@@ -520,15 +530,18 @@ for check how parameter detection works."
   (orgmdb--ensure-response-is-successful info)
   (--each
       (remq 'poster orgmdb-fill-property-list)
-    (-as->
-     (format "orgmdb-%s" it) fn
-     (intern fn)
-     (apply fn `(,info "N/A"))
-     (org-entry-put nil
-                    (if orgmdb-upcase-properties
-                        (upcase (format "%s" it))
-                      (format "%s" it))
-                    fn)))
+    (let* ((key (if orgmdb-upcase-properties
+                    (upcase (format "%s" it))
+                  (format "%s" it)))
+           (val (-as->
+                 (format "orgmdb-%s" it) fn
+                 (intern fn)
+                 (apply fn `(,info ,orgmdb-not-available-property-value))))
+           (unavailable? (equal val orgmdb-not-available-property-value)))
+      (when (or (not unavailable?)
+                (and orgmdb-not-available-property-value
+                     (not (org-entry-get nil key nil))))
+        (org-entry-put nil key val))))
   (when (memq 'poster orgmdb-fill-property-list)
     (let ((path (orgmdb--download-image-for info)))
       (save-excursion
